@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: afstreams.c,v 1.4 1999/08/29 17:37:56 bazsi Exp $
+ * $Id: afstreams.c,v 1.4.2.2 1999/11/15 10:33:34 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -115,7 +115,7 @@ static int do_stream_read(int fd, UINT32 *pri, UINT32 length, UINT8 *buf)
 static void stream_read_callback(struct nonblocking_fd *fd)
 {
 	CAST(stream_fd, self, fd);
-	char line[MAX_LINE];
+	char line[MAX_LINE*10];
 	UINT32 pri;
 	int n;
 	
@@ -134,12 +134,17 @@ static void stream_read_callback(struct nonblocking_fd *fd)
 		eol = memchr(bol, '\n', n);
 
 		while (eol) {
+			while (*bol <= 26) {
+				bol++;
+				n--;
+			}
 
 			length = eol - bol;			
-			li = make_log_info(length, bol);
-			li->pri = pri;
-			HANDLE_LOG(self->pipe, li);
-
+			if (length) {
+				li = make_log_info(length, bol);
+				li->pri = pri;
+				HANDLE_LOG(self->pipe, li);
+			}
 			n -= length + 1;
 			bol = eol + 1;
 			eol = memchr(bol, '\n', n);
@@ -154,12 +159,12 @@ struct nonblocking_fd *io_stream_get(struct io_backend *backend,
 {
 	NEW(stream_fd, f);
 
+	init_file(backend, &f->super, fd);
 	f->super.prepare = prepare_stream_fd;
 	f->super.read = stream_read_callback;
 	f->super.want_read = 1;
 	f->pipe = pipe;
 
-	init_file(backend, &f->super, fd);
 	return &f->super;
 }
 
